% READ_MIXMAPPER_INPUT Imports bootstrap data generated by the
% compute_moment_stats C++ code into Matlab.
%
%   POP_DATA_REPS = READ_MIXMAPPER_INPUT(DATA_PREFIX) imports data from
%   the following three files generated by compute_moment_stats:
%   - DATA_PREFIX.pops.txt        population names
%   - DATA_PREFIX.f2_boots.txt    bootstrap reps of pairwise f2 stats
%   - DATA_PREFIX.h_boots.txt     bootstrap reps of heterozygosities
%   POP_DATA_REPS is a struct array, each element of which contains the
%   following data for a single bootstrap replicate:
%   - f2_all (n x n matrix of pairwise f2 statistics)
%   - het (n vector of heterozygosity values)
%   - pop_names (n cell array)
%
%   POP_DATA_REPS = READ_MIXMAPPER_INPUT(POPS_FILE,F2_FILE,H_FILE)
%   imports data from three files specified explicitly.
%
%   Example:
%
%       % read input data generated by compute_moment_stats (C++ code)
%       pop_data_reps = read_MixMapper_input('example/panel4_thinned_MixMapper');
%       
%   See also MIXMAPPER.


% Mark Lipson and Po-Ru Loh, 12/3/2012

function pop_data_reps = read_MixMapper_input(pops_file_or_prefix,f2_file,h_file)
    if nargin == 1
        data_prefix = pops_file_or_prefix;
        pops_file = [data_prefix '.pops.txt'];
        f2_file = [data_prefix '.f2_boots.txt'];
        h_file = [data_prefix '.h_boots.txt'];
    elseif nargin == 3
        pops_file = pops_file_or_prefix;
    else
        error('wrong number of arguments')
    end
    
    fid = fopen(pops_file);
    pop_names = textscan(fid,'%s'); pop_names = pop_names{1};
    fclose(fid);    
    num_pops = length(pop_names);
    f2_reps = textread(f2_file);
    R = size(f2_reps,2);
    f2_reps = reshape(f2_reps,[num_pops num_pops R]);
    h_reps = textread(h_file);
    
    for r = R:-1:1
        pop_data_reps(r) = struct('f2',f2_reps(:,:,r),'h',h_reps(:,r),'pop_names',{pop_names});
    end
end